@@ -9,11 +9,13 @@ import os
 import os.path as path
 import json
 import re
+import subprocess
 import sys
 import warnings
 from contextlib import contextmanager
 from functools import lru_cache
 from http.server import BaseHTTPRequestHandler, HTTPServer
+from pathlib import Path
 from typing import Dict, List, Sequence
 from warnings import warn
 
@@ -397,6 +399,7 @@ def _generate_lunr_search(modules: List[pdoc.Module],
             info['doc'] = trim_docstring(dobj.docstring)
         if isinstance(dobj, pdoc.Function):
             info['func'] = 1
+        nonlocal index
         index.append(info)
         for member_dobj in getattr(dobj, 'doc', {}).values():
             recursive_add_to_index(member_dobj)
@@ -414,12 +417,30 @@ def _generate_lunr_search(modules: List[pdoc.Module],
         recursive_add_to_index(top_module)
     urls = sorted(url_cache.keys(), key=url_cache.__getitem__)
 
+    cmd = ['node', str(Path(__file__).with_name('build-index.js'))]
+    proc = None
+    try:
+        proc = subprocess.Popen(cmd, text=True, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
+                                stderr=subprocess.PIPE)
+        stdout, stderr = proc.communicate(json.dumps(index))
+        assert proc.poll() == 0, proc.poll()
+    except Exception as ex:
+        stderr = proc and proc.stderr and proc.stderr.read()  # type: ignore
+        warn(f'Prebuilding Lunr index with command `{" ".join(cmd)}` failed with '
+             f'"{ex.__class__.__name__}: {ex}". Stderr: {stderr or ""!r}. '
+             f'Note, the search feature will still work, '
+             f'but may be slower (with the index rebuilt just before use). '
+             f'To prebuild an index in advance, ensure `node` is executable in the '
+             f'pdoc environment.', category=RuntimeWarning)
+        stdout = ('URLS=' + json.dumps(urls, indent=0, separators=(',', ':')) +
+                  ';\nINDEX=' + json.dumps(index, indent=0, separators=(',', ':')))
+    else:
+        stdout = (f'let [INDEX, DOCS] = {stdout}; '
+                  f'let URLS={json.dumps(urls, indent=0, separators=(",", ":"))}')
     main_path = args.output_dir
-    with _open_write_file(path.join(main_path, 'index.js')) as f:
-        f.write("URLS=")
-        json.dump(urls, f, indent=0, separators=(',', ':'))
-        f.write(";\nINDEX=")
-        json.dump(index, f, indent=0, separators=(',', ':'))
+    index_path = Path(main_path).joinpath('index.js')
+    index_path.write_text(stdout)
+    print(str(index_path))
 
     # Generate search.html
     with _open_write_file(path.join(main_path, 'doc-search.html')) as f:
@@ -482,13 +503,13 @@ def main(_args=None):
 
     # Virtual environment handling for pdoc script run from system site
     try:
-        venv_dir = os.environ['VIRTUAL_ENV']
+        os.environ['VIRTUAL_ENV']
     except KeyError:
         pass  # pdoc was not invoked while in a virtual environment
     else:
         from glob import glob
-        from distutils.sysconfig import get_python_lib
-        libdir = get_python_lib(prefix=venv_dir)
+        from sysconfig import get_path
+        libdir = get_path("platlib")
         sys.path.append(libdir)
         # Resolve egg-links from `setup.py develop` or `pip install -e`
         # XXX: Welcome a more canonical approach
@@ -524,18 +545,31 @@ def main(_args=None):
             httpd.server_close()
             sys.exit(0)
 
-    docfilter = None
     if args.filter and args.filter.strip():
         def docfilter(obj, _filters=args.filter.strip().split(',')):
             return any(f in obj.refname or
                        isinstance(obj, pdoc.Class) and f in obj.doc
                        for f in _filters)
+    else:
+        docfilter = None
 
     modules = [pdoc.Module(module, docfilter=docfilter,
                            skip_errors=args.skip_errors)
                for module in args.modules]
     pdoc.link_inheritance()
 
+    # Loading is done. Output stage ...
+    config = pdoc._get_config(**template_config)
+
+    # Load configured global markdown extensions
+    # XXX: This is hereby enabled only for CLI usage as for
+    #  API use I couldn't figure out where reliably to put it.
+    if config.get('md_extensions'):
+        from .html_helpers import _md
+        _kwargs = {'extensions': [], 'configs': {}}
+        _kwargs.update(config.get('md_extensions', {}))
+        _md.registerExtensions(**_kwargs)
+
     if args.pdf:
         _print_pdf(modules, **template_config)
         import textwrap
@@ -582,7 +616,7 @@ or similar, at your own discretion.""",
             sys.stdout.write(os.linesep * (1 + 2 * int(module != modules[-1])))
 
     if args.html:
-        lunr_config = pdoc._get_config(**template_config).get('lunr_search')
+        lunr_config = config.get('lunr_search')
         if lunr_config is not None:
             _generate_lunr_search(
                 modules, lunr_config.get("index_docstrings", True), template_config)
@@ -592,7 +626,7 @@ _PANDOC_COMMAND = '''\
 pandoc --metadata=title:"MyProject Documentation"               \\
        --from=markdown+abbreviations+tex_math_single_backslash  \\
        --pdf-engine=xelatex --variable=mainfont:"DejaVu Sans"   \\
-       --toc --toc-depth=4 --output=pdf.pdf  pdf.md\
+       --toc --toc-depth=4 --output=/tmp/pdoc.pdf  pdf.md
 '''
 
 
