@@ -9,7 +9,7 @@ import textwrap
 import traceback
 from contextlib import contextmanager
 from functools import partial, lru_cache
-from typing import Callable, Match
+from typing import Callable, Match, Optional
 from warnings import warn
 import xml.etree.ElementTree as etree
 
@@ -73,12 +73,12 @@ _md = markdown.Markdown(
     output_format='html5',    # type: ignore[arg-type]
     extensions=[
         "markdown.extensions.abbr",
+        "markdown.extensions.admonition",
         "markdown.extensions.attr_list",
         "markdown.extensions.def_list",
         "markdown.extensions.fenced_code",
         "markdown.extensions.footnotes",
         "markdown.extensions.tables",
-        "markdown.extensions.admonition",
         "markdown.extensions.smarty",
         "markdown.extensions.toc",
     ],
@@ -248,14 +248,14 @@ class _ToMarkdown:
             section = section.title()
             if section in ('Args', 'Attributes'):
                 body = re.compile(
-                    r'^([\w*]+)(?: \(([\w.,=\[\] -]+)\))?: '
+                    r'^([\w*]+)(?: \(([\w.,=|\[\] -]+)\))?: '
                     r'((?:.*)(?:\n(?: {2,}.*|$))*)', re.MULTILINE).sub(
                     lambda m: _ToMarkdown._deflist(*_ToMarkdown._fix_indent(*m.groups())),
                     inspect.cleandoc(f'\n{body}')
                 )
             elif section in ('Returns', 'Yields', 'Raises', 'Warns'):
                 body = re.compile(
-                    r'^()([\w.,\[\] ]+): '
+                    r'^()([\w.,|\[\] ]+): '
                     r'((?:.*)(?:\n(?: {2,}.*|$))*)', re.MULTILINE).sub(
                     lambda m: _ToMarkdown._deflist(*_ToMarkdown._fix_indent(*m.groups())),
                     inspect.cleandoc(f'\n{body}')
@@ -275,6 +275,9 @@ class _ToMarkdown:
         if limit_types and type not in limit_types:
             return match.group(0)
 
+        if text is None:
+            text = ""
+
         if type == 'include' and module:
             try:
                 return _ToMarkdown._include_file(indent, value,
@@ -286,7 +289,7 @@ class _ToMarkdown:
                 '\n': ' ',
                 '[': '\\[',
                 ']': '\\]'})).strip()
-            return f'{indent}![{alt_text}]({value})\n'
+            return f'{indent}![{alt_text}]({value}){{: loading=lazy}}\n'
         if type == 'math':
             return _ToMarkdown.indent(indent,
                                       f'\\[ {text.strip()} \\]',
@@ -323,7 +326,8 @@ class _ToMarkdown:
         See: https://python-markdown.github.io/extensions/admonition/
         """
         substitute = partial(re.compile(r'^(?P<indent> *)\.\. ?(\w+)::(?: *(.*))?'
-                                        r'((?:\n(?:(?P=indent) +.*| *$))*)', re.MULTILINE).sub,
+                                        r'((?:\n(?:(?P=indent) +.*| *$))*[^\r\n])*',
+                                        re.MULTILINE).sub,
                              partial(_ToMarkdown._admonition, module=module,
                                      limit_types=limit_types))
         # Apply twice for nested (e.g. image inside warning)
@@ -404,8 +408,9 @@ class _MathPattern(InlineProcessor):
 
 
 def to_html(text: str, *,
-            docformat: str = None,
-            module: pdoc.Module = None, link: Callable[..., str] = None,
+            docformat: Optional[str] = None,
+            module: Optional[pdoc.Module] = None,
+            link: Optional[Callable[..., str]] = None,
             latex_math: bool = False):
     """
     Returns HTML of `text` interpreted as `docformat`. `__docformat__` is respected
@@ -429,8 +434,9 @@ def to_html(text: str, *,
 
 
 def to_markdown(text: str, *,
-                docformat: str = None,
-                module: pdoc.Module = None, link: Callable[..., str] = None):
+                docformat: Optional[str] = None,
+                module: Optional[pdoc.Module] = None,
+                link: Optional[Callable[..., str]] = None):
     """
     Returns `text`, assumed to be a docstring in `docformat`, converted to markdown.
     `__docformat__` is respected
@@ -558,20 +564,21 @@ def format_git_link(template: str, dobj: pdoc.Doc):
     try:
         if 'commit' in _str_template_fields(template):
             commit = _git_head_commit()
-        abs_path = inspect.getfile(inspect.unwrap(dobj.obj))
+        obj = pdoc._unwrap_descriptor(dobj)
+        abs_path = inspect.getfile(inspect.unwrap(obj))
         path = _project_relative_path(abs_path)
 
         # Urls should always use / instead of \\
         if os.name == 'nt':
             path = path.replace('\\', '/')
 
-        lines, start_line = inspect.getsourcelines(dobj.obj)
+        lines, start_line = inspect.getsourcelines(obj)
         start_line = start_line or 1  # GH-296
         end_line = start_line + len(lines) - 1
         url = template.format(**locals())
         return url
     except Exception:
-        warn(f'format_git_link for {dobj.obj} failed:\n{traceback.format_exc()}')
+        warn(f'format_git_link for {obj} failed:\n{traceback.format_exc()}')
         return None
 
 
@@ -618,9 +625,9 @@ def _project_relative_path(absolute_path):
     Assumes the project's path is either the current working directory or
     Python library installation.
     """
-    from distutils.sysconfig import get_python_lib
-    for prefix_path in (_git_project_root() or os.getcwd(),
-                        get_python_lib()):
+    from sysconfig import get_path
+    libdir = get_path("platlib")
+    for prefix_path in (_git_project_root() or os.getcwd(), libdir):
         common_path = os.path.commonpath([prefix_path, absolute_path])
         if os.path.samefile(common_path, prefix_path):
             # absolute_path is a descendant of prefix_path
