@@ -14,15 +14,18 @@ import threading
 import unittest
 import warnings
 from contextlib import contextmanager, redirect_stderr, redirect_stdout
+from dataclasses import dataclass
 from functools import wraps
 from glob import glob
 from io import StringIO
 from itertools import chain
+from pathlib import Path
 from random import randint
 from tempfile import TemporaryDirectory
 from time import sleep
 from types import ModuleType
-from unittest.mock import patch
+from unittest import expectedFailure
+from unittest.mock import Mock, patch
 from urllib.error import HTTPError
 from urllib.request import Request, urlopen
 
@@ -70,10 +73,10 @@ def run(*args, **kwargs) -> int:
     params = list(filter(None, chain.from_iterable(params)))  # type: ignore
     _args = cli.parser.parse_args([*params, *args])           # type: ignore
     try:
-        returncode = cli.main(_args)
-        return returncode or 0
+        cli.main(_args)
+        return 0
     except SystemExit as e:
-        return e.code
+        return bool(e.code)
 
 
 @contextmanager
@@ -126,7 +129,8 @@ class CliTest(unittest.TestCase):
     def setUp(self):
         pdoc.reset()
 
-    @unittest.skipIf(sys.version_info < (3, 7), 'pdoc._formatannotation fails on Py3.6')
+    @unittest.skipIf(sys.version_info < (3, 10),
+                     'HACK: _formatannotation() changed return value in Py3.10')
     def test_project_doctests(self):
         doctests = doctest.testmod(pdoc)
         assert not doctests.failed and doctests.attempted, doctests
@@ -185,8 +189,12 @@ class CliTest(unittest.TestCase):
             '<object ',
             ' class="ident">_private',
             ' class="ident">_Private',
-            'non_callable_routine',
         ]
+        if sys.version_info >= (3, 10):
+            include_patterns.append('non_callable_routine')
+        else:
+            exclude_patterns.append('non_callable_routine')
+
         package_files = {
             '': self.PUBLIC_FILES,
             '.subpkg2': [f for f in self.PUBLIC_FILES
@@ -245,13 +253,13 @@ class CliTest(unittest.TestCase):
             )
 
     def test_docformat(self):
-        with self.assertWarns(UserWarning) as cm,\
+        with self.assertWarns(UserWarning) as cm, \
                 run_html(EXAMPLE_MODULE, config='docformat="restructuredtext"'):
             self._basic_html_assertions()
         self.assertIn('numpy', cm.warning.args[0])
 
     def test_html_no_source(self):
-        with self.assertWarns(DeprecationWarning),\
+        with self.assertWarns(DeprecationWarning), \
                 run_html(EXAMPLE_MODULE, html_no_source=None):
             self._basic_html_assertions()
             self._check_files(exclude_patterns=['class="source"', 'Hidden'])
@@ -266,8 +274,13 @@ class CliTest(unittest.TestCase):
             files = self.PUBLIC_FILES + ["doc-search.html", "index.js"]
             self._basic_html_assertions(expected_files=files)
             self._check_files(exclude_patterns=['class="gcse-search"'])
-            self._check_files(include_patterns=['URLS=[\n"example_pkg/index.html",\n"example_pkg/'],
-                              file_pattern='index.js')
+            if shutil.which('node'):
+                self._check_files(include_patterns=['{"version"', 'pdoc.Doc'],
+                                  file_pattern='index.js')
+            else:
+                self._check_files(
+                    include_patterns=['URLS=[\n"example_pkg/index.html",\n"example_pkg/'],
+                    file_pattern='index.js')
             self._check_files(include_patterns=["'../doc-search.html#'"],
                               file_pattern='example_pkg/index.html')
             self._check_files(include_patterns=["'../doc-search.html#'"],
@@ -296,7 +309,7 @@ class CliTest(unittest.TestCase):
             self._basic_html_assertions()
             self._check_files(exclude_patterns=['<a href="/sys.version.ext"'])
 
-        with self.assertWarns(DeprecationWarning),\
+        with self.assertWarns(DeprecationWarning), \
                 run_html(EXAMPLE_MODULE, external_links=None):
             self._basic_html_assertions()
             self._check_files(['<a title="sys.version" href="/sys.version.ext"'])
@@ -314,7 +327,7 @@ class CliTest(unittest.TestCase):
             pdoc.tpl_lookup._collection.clear()
 
     def test_link_prefix(self):
-        with self.assertWarns(DeprecationWarning),\
+        with self.assertWarns(DeprecationWarning), \
                 run_html(EXAMPLE_MODULE, link_prefix='/foobar/'):
             self._basic_html_assertions()
             self._check_files(['/foobar/' + EXAMPLE_MODULE])
@@ -350,14 +363,19 @@ class CliTest(unittest.TestCase):
             'B.p docstring',
             'C',
             'B.overridden docstring',
+            'function_mock',
+            'coroutine_mock',
         ]
         exclude_patterns = [
             '_private',
             '_Private',
             'subprocess',
             'Hidden',
-            'non_callable_routine',
         ]
+        if sys.version_info >= (3, 10):
+            include_patterns.append('non_callable_routine')
+        else:
+            exclude_patterns.append('non_callable_routine')
 
         with self.subTest(package=EXAMPLE_MODULE):
             with redirect_streams() as (stdout, _):
@@ -409,7 +427,7 @@ class CliTest(unittest.TestCase):
             run('pdoc', pdf=None)
             f.write(stdout.getvalue())
             subprocess.run(pdoc.cli._PANDOC_COMMAND, shell=True, check=True)
-            self.assertTrue(os.path.exists('pdf.pdf'))
+            self.assertTrue(os.path.exists('/tmp/pdoc.pdf'))
 
     def test_config(self):
         with run_html(EXAMPLE_MODULE, config='link_prefix="/foobar/"'):
@@ -425,10 +443,10 @@ class CliTest(unittest.TestCase):
                                              for file in self.PUBLIC_FILES])
 
     def test_google_analytics(self):
-        expected = ['google-analytics.com']
+        expected = ['googletagmanager.com']
         with run_html(EXAMPLE_MODULE):
             self._check_files((), exclude_patterns=expected)
-        with run_html(EXAMPLE_MODULE, config='google_analytics="UA-xxxxxx-y"'):
+        with run_html(EXAMPLE_MODULE, config='google_analytics="G-xxxxxxxxxx"'):
             self._check_files(expected)
 
     def test_relative_dir_path(self):
@@ -437,11 +455,12 @@ class CliTest(unittest.TestCase):
                 self._check_files(())
 
     def test_skip_errors(self):
-        with chdir(os.path.join(TESTS_BASEDIR, EXAMPLE_MODULE, '_skip_errors')),\
-                redirect_streams(),\
+        with chdir(os.path.join(TESTS_BASEDIR, EXAMPLE_MODULE, '_skip_errors')), \
+                redirect_streams(), \
                 self.assertWarns(pdoc.Module.ImportWarning) as cm:
             run('.', skip_errors=None)
-        self.assertIn('ZeroDivision', cm.warning.args[0])
+            run('unimportable', skip_errors=None)
+        self.assertEqual(2, sum(1 for w in cm.warnings if 'ZeroDivision' in str(w.message)))
 
     @unittest.skipIf(sys.version_info < (3, 7), '__future__.annotations unsupported in <Py3.7')
     def test_resolve_typing_forwardrefs(self):
@@ -460,6 +479,15 @@ class CliTest(unittest.TestCase):
             out = out.getvalue()
             self.assertIn('Set[Bar]', out)
 
+    def test_md_extensions(self):
+        with temp_dir() as path, chdir(path):
+            Path('foo.py').write_text('"""secret: meta data\n\nOnly this comment expected."""')
+            with redirect_streams() as (stdout, _), \
+                    run_html('foo.py',
+                             config="md_extensions={'extensions': ['markdown.extensions.meta']}",):
+                self._check_files(include_patterns=['<p>Only this comment expected.</p>'],
+                                  exclude_patterns=['<p>secret: meta data</p>'])
+
 
 class ApiTest(unittest.TestCase):
     """
@@ -540,11 +568,13 @@ class ApiTest(unittest.TestCase):
             but_clss_have_doc = int
 
         doc = pdoc.Class('C', DUMMY_PDOC_MODULE, C)
-        self.assertEqual(doc.doc['vars_dont'].docstring, '')
+        expected = 'The type of the None singleton.' if sys.version_info > (3, 13) else ''
+        self.assertEqual(doc.doc['vars_dont'].docstring, expected)
         self.assertIn('integer', doc.doc['but_clss_have_doc'].docstring)
 
+    @unittest.skipIf(sys.version_info >= (3, 10), 'No builtin module "parser" in Py3.10')
     def test_builtin_methoddescriptors(self):
-        import parser
+        import parser  # TODO: replace with another public binary builtin
         with self.assertWarns(UserWarning):
             c = pdoc.Class('STType', pdoc.Module(parser), parser.STType)
         self.assertIsInstance(c.doc['compile'], pdoc.Function)
@@ -906,9 +936,13 @@ class ApiTest(unittest.TestCase):
         def bug253_newtype_annotation(a: CustomType):
             return
 
+        expected = CustomType.__name__
+        if sys.version_info > (3, 10):
+            expected = f'{__name__}.{CustomType.__name__}'
+
         self.assertEqual(
             pdoc.Function('bug253', mod, bug253_newtype_annotation).params(annotate=True),
-            ['a:\N{NBSP}CustomType'])
+            [f'a:\N{NBSP}{expected}'])
 
         # typing.Callable bug
         def f(a: typing.Callable):
@@ -940,9 +974,9 @@ class ApiTest(unittest.TestCase):
         self.assertEqual(func.params(), ['a', '/'])
 
     def test_Function_return_annotation(self):
-        def f() -> typing.List[typing.Union[str, pdoc.Doc]]: pass
+        def f() -> typing.List[typing.Union[str, pdoc.Doc]]: return []
         func = pdoc.Function('f', DUMMY_PDOC_MODULE, f)
-        self.assertEqual(func.return_annotation(), 'List[Union[str,\N{NBSP}pdoc.Doc]]')
+        self.assertEqual(func.return_annotation(), 'List[str\N{NBSP}|\N{NBSP}pdoc.Doc]')
 
     @ignore_warnings
     def test_Variable_type_annotation(self):
@@ -953,7 +987,7 @@ class ApiTest(unittest.TestCase):
 
         mod = DUMMY_PDOC_MODULE
         cls = pdoc.Class('Foobar', mod, Foobar)
-        self.assertEqual(cls.doc['prop'].type_annotation(), 'Optional[int]')
+        self.assertEqual(cls.doc['prop'].type_annotation(), 'int\N{NBSP}|\N{NBSP}None')
 
     @ignore_warnings
     def test_Variable_type_annotation_py36plus(self):
@@ -1043,16 +1077,20 @@ class Foo:
 
         self.assertEqual(pdoc.Class('C2', mod, C2).params(), ['a', 'b', 'c=None', '*', 'd=1', 'e'])
 
-        class G(typing.Generic[T]):
+        class ClassWithNew:
+            def __new__(self, arg):
+                pass
+
+        class G(ClassWithNew):
             def __init__(self, a, b, c=100):
                 pass
 
         self.assertEqual(pdoc.Class('G', mod, G).params(), ['a', 'b', 'c=100'])
 
-        class G2(typing.Generic[T]):
+        class G2(ClassWithNew):
             pass
 
-        self.assertEqual(pdoc.Class('G2', mod, G2).params(), ['*args', '**kwds'])
+        self.assertEqual(pdoc.Class('G2', mod, G2).params(), ['arg'])
 
     def test_url(self):
         mod = pdoc.Module(EXAMPLE_MODULE)
@@ -1157,6 +1195,11 @@ class C:
             self.assertEqual(mod.doc['C'].doc['class_var'].docstring, 'class var')
             self.assertEqual(mod.doc['C'].doc['instance_var'].docstring, 'instance var')
 
+    @expectedFailure
+    def test_mock_signature_error(self):
+        # GH-350 -- throws `TypeError: 'Mock' object is not subscriptable`:
+        self.assertIsInstance(inspect.signature(Mock(spec=lambda x: x)), inspect.Signature)
+
 
 class HtmlHelpersTest(unittest.TestCase):
     """
@@ -1427,6 +1470,8 @@ Nomatch:</p>
 <dd>Description of arg1</dd>
 <dt><strong><code>arg2</code></strong> :&ensp;<code>str</code> or <code>int</code></dt>
 <dd>Description of arg2</dd>
+<dt><strong><code>arg3</code></strong> :&ensp;<code>str | None</code></dt>
+<dd>Description of arg3</dd>
 <dt><strong><code>test_sequence</code></strong></dt>
 <dd>
 <p>2-dim numpy array of real numbers, size: N * D
@@ -1454,6 +1499,11 @@ which is the answer of everything.</p>
 <dt><code>Dict[int, <a>pdoc.Doc</a>]</code></dt>
 <dd>Description.</dd>
 </dl>
+<h2 id="returns_3">Returns</h2>
+<dl>
+<dt><code>int | str</code></dt>
+<dd>Description.</dd>
+</dl>
 <h2 id="raises">Raises</h2>
 <dl>
 <dt><code>AttributeError</code></dt>
@@ -1523,13 +1573,13 @@ Exception: something went wrong
 <div class="admonition admonition">
 <p class="admonition-title">Example</p>
 <p>Image shows something.</p>
-<p><img alt="" src="https://www.debian.org/logos/openlogo-nd-100.png"></p>
+<p><img alt="" loading="lazy" src="https://www.debian.org/logos/openlogo-nd-100.png"></p>
 <div class="admonition note">
 <p class="admonition-title">Note</p>
 <p>Can only nest admonitions two levels.</p>
 </div>
 </div>
-<p><img alt="" src="https://www.debian.org/logos/openlogo-nd-100.png"></p>
+<p><img alt="" loading="lazy" src="https://www.debian.org/logos/openlogo-nd-100.png"></p>
 <p>Now you know.</p>
 <div class="admonition warning">
 <p class="admonition-title">Warning</p>
@@ -1564,7 +1614,22 @@ lines.</p>
 <p>1
 x = 2
 x = 3
-x =</p>'''
+x =</p>
+<table>
+<thead>
+<tr>
+<th>Name</th>
+<th>Value</th>
+</tr>
+</thead>
+<tbody>
+<tr>
+<td>Hello</td>
+<td>World</td>
+</tr>
+</tbody>
+</table>
+<p>Remaining.</p>'''
         mod = pdoc.Module(pdoc.import_module(
             os.path.join(TESTS_BASEDIR, EXAMPLE_MODULE, '_reST_include', 'test.py')))
         html = to_html(mod.docstring, module=mod)
@@ -1625,6 +1690,8 @@ text <code>x ` http://foo</code> <a href="http://bar">http://bar</a> <code>http:
         expected = r'''<p>Inline equation: <span><span class="MathJax_Preview"> v_t *\frac{1}{2}* j_i + [a] &lt; 3 </span><script type="math/tex"> v_t *\frac{1}{2}* j_i + [a] < 3 </script></span>.</p>
 <p>Block equation: <span><span class="MathJax_Preview"> v_t *\frac{1}{2}* j_i + [a] &lt; 3 </span><script type="math/tex; mode=display"> v_t *\frac{1}{2}* j_i + [a] < 3 </script></span></p>
 <p>Block equation: <span><span class="MathJax_Preview"> v_t *\frac{1}{2}* j_i + [a] &lt; 3 </span><script type="math/tex; mode=display"> v_t *\frac{1}{2}* j_i + [a] < 3 </script></span></p>
+<p>$\mathcal{O}(N)$</p>
+<p>Escaping \$ should work in math like $X = \$3.25$ once it is implemented.</p>
 <p><span><span class="MathJax_Preview"> v_t *\frac{1}{2}* j_i + [a] &lt; 3 </span><script type="math/tex; mode=display"> v_t *\frac{1}{2}* j_i + [a] < 3 </script></span></p>'''  # noqa: E501
         text = inspect.getdoc(self._docmodule.latex_math)
         html = to_html(text, module=self._module, link=self._link, latex_math=True)
@@ -1669,6 +1736,9 @@ class HttpTest(unittest.TestCase):
                 t.start()
                 sleep(.1)
 
+                assert sys.__stderr__ and sys.__stdout__, \
+                    'https://docs.python.org/3/library/sys.html#sys.__stdout__'
+
                 if not t.is_alive():
                     sys.__stderr__.write(stderr.getvalue())
                     raise AssertionError
@@ -1719,5 +1789,16 @@ class HttpTest(unittest.TestCase):
             self.assertEqual(cm.exception.code, 304)
 
 
+class RegressionsTest(unittest.TestCase):
+    def test_dataclass_has_instance_vars(self):
+        @dataclass
+        class Foo:
+            bar: int  #: baz
+
+        obj = pdoc.Class(Foo.__name__, pdoc.Module(EMPTY_MODULE), Foo)
+        self.assertTrue(obj.doc['bar'].instance_var)
+        self.assertEqual(obj.doc['bar'].docstring, 'baz')
+
+
 if __name__ == '__main__':
     unittest.main()
